@@ -5,7 +5,7 @@ use strict;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-02-03'; # DATE
 our $DIST = 'Sah-Schemas-Array'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 our $schema = [array => {
     summary => 'An array of integers with monotonically increasing elements',
@@ -44,7 +44,7 @@ Sah::Schema::array::int::monotonically_increasing - An array of integers with mo
 
 =head1 VERSION
 
-This document describes version 0.002 of Sah::Schema::array::int::monotonically_increasing (from Perl distribution Sah-Schemas-Array), released on 2023-02-03.
+This document describes version 0.003 of Sah::Schema::array::int::monotonically_increasing (from Perl distribution Sah-Schemas-Array), released on 2023-02-03.
 
 =head1 SYNOPSIS
 
@@ -82,12 +82,12 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data);
  
  # a sample valid data
- $data = [];
+ $data = [1,2,3];
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
- $data = [1,"a"];
- my $errmsg = $validator->($data); # => "Elements not monotonically increasing (check element[1]) "
+ $data = [1,3,2];
+ my $errmsg = $validator->($data); # => "Elements not monotonically increasing (check element[2]) "
 
 Often a schema has coercion rule or default value, so after validation the
 validated value is different. To return the validated (set-as-default, coerced,
@@ -97,12 +97,12 @@ prefiltered) value:
  my $res = $validator->($data); # [$errmsg, $validated_val]
  
  # a sample valid data
- $data = [];
- my $res = $validator->($data); # => ["",[]]
+ $data = [1,2,3];
+ my $res = $validator->($data); # => ["",[1,2,3]]
  
  # a sample invalid data
- $data = [1,"a"];
- my $res = $validator->($data); # => ["Elements not monotonically increasing (check element[1]) ",[1,"a"]]
+ $data = [1,3,2];
+ my $res = $validator->($data); # => ["Elements not monotonically increasing (check element[2]) ",[1,3,2]]
 
 Data::Sah can also create validator that returns a hash of detailed error
 message. Data::Sah can even create validator that targets other language, like
