@@ -5,7 +5,7 @@ use strict;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-02-03'; # DATE
 our $DIST = 'Sah-Schemas-Array'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 our $schema = [array => {
     summary => 'An array of sorted integers',
@@ -43,7 +43,7 @@ Sah::Schema::array::int::sorted - An array of sorted integers
 
 =head1 VERSION
 
-This document describes version 0.002 of Sah::Schema::array::int::sorted (from Perl distribution Sah-Schemas-Array), released on 2023-02-03.
+This document describes version 0.003 of Sah::Schema::array::int::sorted (from Perl distribution Sah-Schemas-Array), released on 2023-02-03.
 
 =head1 SYNOPSIS
 
@@ -81,12 +81,12 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data);
  
  # a sample valid data
- $data = [1,2,2];
+ $data = [1,2,3];
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
- $data = {};
- my $errmsg = $validator->($data); # => "Not an array"
+ $data = [1,2.9,3];
+ my $errmsg = $validator->($data); # => "\@[1]: Not of type integer"
 
 Often a schema has coercion rule or default value, so after validation the
 validated value is different. To return the validated (set-as-default, coerced,
@@ -96,12 +96,12 @@ prefiltered) value:
  my $res = $validator->($data); # [$errmsg, $validated_val]
  
  # a sample valid data
- $data = [1,2,2];
- my $res = $validator->($data); # => ["",[1,2,2]]
+ $data = [1,2,3];
+ my $res = $validator->($data); # => ["",[1,2,3]]
  
  # a sample invalid data
- $data = {};
- my $res = $validator->($data); # => ["Not an array",{}]
+ $data = [1,2.9,3];
+ my $res = $validator->($data); # => ["\@[1]: Not of type integer",[1,2.9,3]]
 
 Data::Sah can also create validator that returns a hash of detailed error
 message. Data::Sah can even create validator that targets other language, like
