@@ -5,7 +5,7 @@ use strict;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-02-03'; # DATE
 our $DIST = 'Sah-Schemas-Array'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 our $schema = [array => {
     summary => 'An array of numbers with monotonically decreasing elements',
@@ -47,7 +47,7 @@ Sah::Schema::array::num::monotonically_decreasing - An array of numbers with mon
 
 =head1 VERSION
 
-This document describes version 0.002 of Sah::Schema::array::num::monotonically_decreasing (from Perl distribution Sah-Schemas-Array), released on 2023-02-03.
+This document describes version 0.003 of Sah::Schema::array::num::monotonically_decreasing (from Perl distribution Sah-Schemas-Array), released on 2023-02-03.
 
 =head1 SYNOPSIS
 
@@ -89,8 +89,8 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
- $data = {};
- my $errmsg = $validator->($data); # => "Not an array"
+ $data = [3,2,2,1];
+ my $errmsg = $validator->($data); # => "Elements not monotonically increasing (check element[2]) "
 
 Often a schema has coercion rule or default value, so after validation the
 validated value is different. To return the validated (set-as-default, coerced,
@@ -104,8 +104,8 @@ prefiltered) value:
  my $res = $validator->($data); # => ["",[]]
  
  # a sample invalid data
- $data = {};
- my $res = $validator->($data); # => ["Not an array",{}]
+ $data = [3,2,2,1];
+ my $res = $validator->($data); # => ["Elements not monotonically increasing (check element[2]) ",[3,2,2,1]]
 
 Data::Sah can also create validator that returns a hash of detailed error
 message. Data::Sah can even create validator that targets other language, like
