@@ -5,7 +5,7 @@ use strict;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-02-03'; # DATE
 our $DIST = 'Sah-Schemas-Array'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 our $schema = [array => {
     summary => 'An array of numbers with monotonically increasing elements',
@@ -46,7 +46,7 @@ Sah::Schema::array::num::monotonically_increasing - An array of numbers with mon
 
 =head1 VERSION
 
-This document describes version 0.002 of Sah::Schema::array::num::monotonically_increasing (from Perl distribution Sah-Schemas-Array), released on 2023-02-03.
+This document describes version 0.003 of Sah::Schema::array::num::monotonically_increasing (from Perl distribution Sah-Schemas-Array), released on 2023-02-03.
 
 =head1 SYNOPSIS
 
@@ -86,8 +86,8 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
- $data = {};
- my $errmsg = $validator->($data); # => "Not an array"
+ $data = [1,"a"];
+ my $errmsg = $validator->($data); # => "Elements not monotonically increasing (check element[1]) "
 
 Often a schema has coercion rule or default value, so after validation the
 validated value is different. To return the validated (set-as-default, coerced,
@@ -101,8 +101,8 @@ prefiltered) value:
  my $res = $validator->($data); # => ["",[]]
  
  # a sample invalid data
- $data = {};
- my $res = $validator->($data); # => ["Not an array",{}]
+ $data = [1,"a"];
+ my $res = $validator->($data); # => ["Elements not monotonically increasing (check element[1]) ",[1,"a"]]
 
 Data::Sah can also create validator that returns a hash of detailed error
 message. Data::Sah can even create validator that targets other language, like
