@@ -5,7 +5,7 @@ use strict;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-02-03'; # DATE
 our $DIST = 'Sah-Schemas-Array'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 our $schema = [array => {
     summary => 'An array of sorted numbers',
@@ -46,7 +46,7 @@ Sah::Schema::array::num::sorted - An array of sorted numbers
 
 =head1 VERSION
 
-This document describes version 0.002 of Sah::Schema::array::num::sorted (from Perl distribution Sah-Schemas-Array), released on 2023-02-03.
+This document describes version 0.003 of Sah::Schema::array::num::sorted (from Perl distribution Sah-Schemas-Array), released on 2023-02-03.
 
 =head1 SYNOPSIS
 
@@ -86,8 +86,8 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
- $data = [1,3,2];
- my $errmsg = $validator->($data); # => "Elements not numerically sorted (check element[2]) "
+ $data = [1,undef];
+ my $errmsg = $validator->($data); # => "Elements not numerically sorted (check element[1]) "
 
 Often a schema has coercion rule or default value, so after validation the
 validated value is different. To return the validated (set-as-default, coerced,
@@ -101,8 +101,8 @@ prefiltered) value:
  my $res = $validator->($data); # => ["",[1,2.9,3]]
  
  # a sample invalid data
- $data = [1,3,2];
- my $res = $validator->($data); # => ["Elements not numerically sorted (check element[2]) ",[1,3,2]]
+ $data = [1,undef];
+ my $res = $validator->($data); # => ["Elements not numerically sorted (check element[1]) ",[1,undef]]
 
 Data::Sah can also create validator that returns a hash of detailed error
 message. Data::Sah can even create validator that targets other language, like
